@@ -1,7 +1,8 @@
 _A=False
 import threading
+from contextlib import ContextDecorator
 from typing import Any,Optional,Type
-class DisableDetail:
+class DisableDetail(ContextDecorator):
 	threadlocal=threading.local()
 	def __enter__(A):A.threadlocal.disabled=True
 	def __exit__(A,exc_type,exc_value,exc_traceback):A.threadlocal.disabled=_A
