@@ -4,7 +4,7 @@ from typing import Collection
 from opentelemetry.instrumentation.instrumentor import BaseInstrumentor
 from opentelemetry.trace import get_tracer
 from wrapt import wrap_function_wrapper
-from detail.client.instrumentation import get_pure_wrapper
+from detail.client.instrumentation.wrappers import get_pure_wrapper
 class CeleryInstrumentor(BaseInstrumentor):
 	targets=[('kombu.common','oid_from',{_A:True}),('celery.utils.nodenames','anon_nodename',{_A:True})]
 	def instrumentation_dependencies(A):return[_B]
