@@ -5,8 +5,9 @@ import psycopg2,wrapt
 from opentelemetry.instrumentation.instrumentor import BaseInstrumentor
 from opentelemetry.trace import get_tracer
 from wrapt import wrap_function_wrapper
-from detail.client.instrumentation import ddpsycopg2,get_pure_wrapper
+from detail.client.instrumentation import ddpsycopg2
 from detail.client.instrumentation.dbapi import TracedConnection,get_connect_wrapper
+from detail.client.instrumentation.wrappers import get_pure_wrapper
 from detail.client.logs import get_detail_logger
 logger=get_detail_logger(__name__)
 class TracedConnectionInfo(wrapt.ObjectProxy):
