@@ -2,7 +2,7 @@ from typing import Collection
 from opentelemetry.instrumentation.instrumentor import BaseInstrumentor
 from opentelemetry.trace import get_tracer
 from wrapt import wrap_function_wrapper
-from detail.client.instrumentation import get_pure_wrapper
+from detail.client.instrumentation.wrappers import get_pure_wrapper
 class RedisInstrumentor(BaseInstrumentor):
 	__version__='0.1'
 	def instrumentation_dependencies(A):return['redis >= 2.6']
