@@ -3,7 +3,7 @@ from typing import Collection
 from opentelemetry.instrumentation.instrumentor import BaseInstrumentor
 from opentelemetry.trace import get_tracer
 from wrapt import wrap_function_wrapper
-from detail.client.instrumentation import force_function_wrapper,get_pure_wrapper
+from detail.client.instrumentation.wrappers import force_function_wrapper,get_pure_wrapper
 class TimeInstrumentor(BaseInstrumentor):
 	time_functions=['time','monotonic','perf_counter','localtime','gmtime','time_ns','monotonic_ns','perf_counter_ns']
 	def instrumentation_dependencies(A):return[]
