@@ -10,9 +10,9 @@ def _is_in_patterns(s,patterns):
 		A=B.search(s)
 		if A:return A
 def get_thread_name():return threading.current_thread().name
-def in_sentry_thread():return'sentry-sdk'in get_thread_name()
-def is_ignored_instrumentation_caller(caller_path):return in_sentry_thread()or _is_in_patterns(caller_path,IGNORED_INSTRUMENTATION_CALLER_PATTERNS)
-def is_ignored_interception_caller(caller_path):return in_sentry_thread()or _is_in_patterns(caller_path,IGNORED_INTERCEPTION_CALLER_PATTERNS)
+def in_ignored_thread():A=get_thread_name();return A=='OtelBatchSpanProcessor'
+def is_ignored_instrumentation_caller(caller_path):return in_ignored_thread()or _is_in_patterns(caller_path,IGNORED_INSTRUMENTATION_CALLER_PATTERNS)
+def is_ignored_interception_caller(caller_path):return in_ignored_thread()or _is_in_patterns(caller_path,IGNORED_INTERCEPTION_CALLER_PATTERNS)
 def get_caller_path(depth=1):
 	B='site-packages';A,*C=get_caller_frameinfo(depth+1)
 	if B in A:A=''.join(A.split(B)[1:]);A=A[1:]
